@@ -19,16 +19,18 @@ struct TxInfo {
     int start;
     int end;
     std::string strand;
+    std::string transcript_type;
     std::vector<std::vector<int> > exons;
     std::vector<std::vector<int> > cds;
     int offset = 0;
+    int is_canonical = 0;
 };
 
 // stores HGNC symbol with the transcript, so we can collect transcripts by gene
 struct NamedTx {
     std::string symbol;
     Tx tx;
-    bool is_principal;
+    int is_canonical;
 };
 
 struct GenePoint {
