@@ -29,7 +29,7 @@ std::unordered_map<std::string, char> aa_code = {
 
 // Constructor for Tx class
 Tx::Tx(std::string transcript_id, std::string chromosome,
-    int start_pos, int end_pos, char strand) {
+    int start_pos, int end_pos, char strand, std::string _transcript_type="protein_coding") {
     
     name = transcript_id;
     
@@ -41,6 +41,7 @@ Tx::Tx(std::string transcript_id, std::string chromosome,
         throw std::invalid_argument( "unknown strand type" );
     }
     tx_strand = strand;
+    transcript_type = _transcript_type;
 }
 
 // set exon ranges to the class object
@@ -637,6 +638,11 @@ int Tx::get_boundary_distance(int bp) {
     return distance;
 }
 
+// check for overlap of two ranges
+bool overlap(const int & start1, const int & end1, const int & start2, const int & end2) {
+    return (end1 >= start2) && (end2 >= start1);
+}
+
 // checks if a genomic range overlaps any exon range
 bool Tx::overlaps_cds(int start, int end) {
     // find the
@@ -644,11 +650,11 @@ bool Tx::overlaps_cds(int start, int end) {
     int prev = std::max(0, idx - 1);
     int post = std::min((int) cds.size() - 1, idx + 1);
     
-    if (start <= cds[idx].end && cds[idx].start < end) {
+    if (overlap(start, end, cds[idx].start, cds[idx].end)) {
         return true;
-    } else if (start < cds[prev].end && cds[prev].start < end) {
+    } else if (overlap(start, end, cds[prev].start, cds[prev].end)) {
         return true;
-    } else if (start < cds[post].end && cds[post].start < end) {
+    } else if (overlap(start, end, cds[post].start, cds[post].end)) {
         return true;
     }
     return false;
@@ -656,13 +662,13 @@ bool Tx::overlaps_cds(int start, int end) {
 
 std::string Tx::outside_gene_cq(int start, int end, std::string alt) {
     bool fwd = get_strand() == '+';
-    if ((end < tx_start) & ((tx_start - end) < 5000)) {
+    if ((end < tx_start) & ((tx_start - end) <= 5000)) {
         if (fwd) {
             return "upstream_gene_variant";
         } else {
             return "downstream_gene_variant";
         }
-    } else if ((start > tx_end) & ((start - tx_end) < 5000)) {
+    } else if ((start > tx_end) & ((start - tx_end) <= 5000)) {
         if (fwd) {
             return "downstream_gene_variant";
         } else {
@@ -677,11 +683,11 @@ std::string Tx::intronic_cq(int start, int end) {
     // figure out if we are in a very short intron
     auto idx = closest_exon_num(start);
     auto exon = exons[idx];
-    int intron_length;
-    if (exon.end < start) {
+    int intron_length = 100;
+    if ((exon.end < start) & (idx < ((int) exons.size() - 1))) {
         auto other = exons[idx + 1];
         intron_length = other.start - exon.end;
-    } else {
+    } else if ((end < exon.start) & (idx > 0)) {
         auto other = exons[idx - 1];
         intron_length = exon.start - other.end;
     }
@@ -702,6 +708,11 @@ std::string Tx::intronic_cq(int start, int end) {
         }
     }
     
+    // TODO: indels near the splice region can duplicate the local sequence.
+    // TODO: In those cases, the splice site might remain unaltered. This means
+    // TODO: the variant location might need to be adjusted. For this, we'd need 
+    // TODO: to check the ref genome vs the replacement, to adjust indel coords.
+    
     // ok, now we have intronic variants, so we check for splice variants first
     int delta = std::min(std::abs(start_coord.offset), std::abs(end_coord.offset));
     if ((delta < 3) & (start_coord.offset < 0)) {
@@ -715,6 +726,58 @@ std::string Tx::intronic_cq(int start, int end) {
     return "intron_variant";
 }
 
+// check consequences for an indel with some CDS overlap
+std::string Tx::indel_cq(int start, int end, std::string ref, std::string alt) {
+    // find the overlapped exon, then check how much of the indel lies in that
+    int idx = closest_exon_num(start);
+    int prev = std::max(0, idx - 1);
+    int post = std::min((int) exons.size() - 1, idx + 1);
+    
+    Region exon;
+    if (overlap(start, end, exons[idx].start, exons[idx].end)) {
+        exon = exons[idx];
+    } else if (overlap(start, end, exons[prev].start, exons[prev].end)) {
+        exon = exons[prev];
+    } else if (overlap(start, end, exons[post].start, exons[post].end)) {
+        exon = exons[post];
+    }
+    
+    bool deletion = ref.size() > alt.size();
+    bool overlaps_intron = false;
+    if (deletion & (start < exon.start)) {
+        overlaps_intron = true;
+        int offset = exon.start - start;
+        int length = (int) ref.size() - offset;
+        ref = ref.substr(offset, length);
+        alt = "";
+    } else if (deletion & (end > exon.end)) {
+        overlaps_intron = true;
+        int offset = 0;
+        int length = (exon.end - start) + 1;
+        ref = ref.substr(offset, length);
+        alt = "";
+    }
+    
+    int ref_len = ref.size();
+    int alt_len = alt.size();
+    bool inframe = ((ref_len - alt_len) % 3) == 0;
+    if (overlaps_intron & inframe & deletion) {
+        // deletions which overlap the exon boundary, but only excise an inframe
+        // length of the exon should be splice donor instead, since they are
+        // more severe than inframe.
+        return "splice_donor_variant";
+    }
+    
+    if (!inframe) {
+        return "frameshift_variant";
+    } else if (deletion) {
+        // TODO: account for new stop sites, or altered splice boundaries
+        return "inframe_deletion";
+    } else {
+        return "inframe_insertion";
+    }
+}
+
 std::string Tx::coding_cq(int start, int end, std::string alt) {
     if (get_strand() == '-') {
         alt = reverse_complement(alt);
@@ -722,7 +785,7 @@ std::string Tx::coding_cq(int start, int end, std::string alt) {
     // TODO: figure out initial and mutated amino acids
     Codon codon = get_codon_info(start);
     char initial_aa = codon.initial_aa;
-    codon.codon_seq[1] = alt[0];
+    codon.codon_seq[codon.intra_codon] = alt[0];
     char mutated_aa = translate_codon(codon.codon_seq);
     
     if (initial_aa != '*' && mutated_aa == '*') { return "stop_gained"; }
@@ -748,8 +811,7 @@ int min_len(std::string a, std::string b) {
 }
 
 // realign alt against ref sequence, and strip down to alternate bases
-void Tx::trim_alleles(int& start, int& end, std::string& alt) {
-    std::string ref = get_seq_in_region(start, end + 1);
+void Tx::trim_alleles(int& start, int&end, std::string& ref, std::string& alt) {
     // trim the front of the alleles
     while ((min_len(ref, alt) > 0) && (ref.size() > 1) && (alt[0] == ref[0])) {
         ref.erase(0, 1);
@@ -765,36 +827,28 @@ void Tx::trim_alleles(int& start, int& end, std::string& alt) {
     }
 }
 
-std::string Tx::consequence(int start, int end, std::string alt) {
+std::string Tx::consequence(int pos, std::string ref, std::string alt) {
+    int start = pos;
+    int end = pos + ref.size() - 1;
     if (start > end) {
         throw std::invalid_argument("start position is less than end position");
     }
     
-    if ((end <= tx_start) | (start >= tx_end)) {
+    // TODO: need to realign alt against ref sequence, and strip down to alternate bases
+    trim_alleles(start, end, ref, alt);
+    
+    if ((end < tx_start) | (start > tx_end)) {
         return outside_gene_cq(start, end, alt);
     }
     
-    // TODO: need to realign alt against ref sequence, and strip down to alternate bases
-    trim_alleles(start, end, alt);
-    
     if (!overlaps_cds(start, end)) {
         return intronic_cq(start, end);
     }
     
     // at this point we know that the site lies within the gene boundary, and
     // at least partially overlaps the CDS
-    std::string ref = get_seq_in_region(start, end+1);
-    int ref_len = ref.size();
-    int alt_len = alt.size();
-    int delta = ref_len - alt_len;
     if (ref.size() != alt.size()) {
-        if ((delta % 3) != 0) {
-            return "frameshift_variant";
-        } else if (ref_len > alt_len) {
-            return "inframe_deletion";
-        } else if (alt_len > ref_len) {
-            return "inframe_insertion";
-        }
+        return indel_cq(start, end, ref, alt);
     }
     
     return coding_cq(start, end, alt);
