@@ -35,6 +35,7 @@ class Tx {
     int cds_min;
     int cds_max;
     int cds_length;
+    std::string transcript_type;
     std::vector<Region> exons;
     std::vector<Region> cds;
     std::string cds_sequence = "";
@@ -45,15 +46,16 @@ class Tx {
     void _cache_exon_cds_positions();
     
     void _fix_cds_length();
-    void trim_alleles(int& start, int& end, std::string& alt);
+    void trim_alleles(int& start, int& end, std::string& ref, std::string& alt);
     bool overlaps_cds(int start, int end);
     std::string outside_gene_cq(int start, int end, std::string alt);
     std::string intronic_cq(int start, int end);
     std::string coding_cq(int start, int end, std::string alt);
+    std::string indel_cq(int start, int end, std::string ref, std::string alt);
 
  public:
     Tx(std::string transcript_id, std::string chromosome, int start_pos,
-        int end_pos, char strand);
+        int end_pos, char strand, std::string _transcript_type);
     Tx() {};
     void set_exons(std::vector<std::vector<int>> exon_ranges,
         std::vector<std::vector<int>> cds_ranges);
@@ -64,6 +66,7 @@ class Tx {
     std::vector<Region> get_cds() { return cds; }
     std::string get_name() { return name; }
     std::string get_chrom() { return chrom; }
+    std::string get_type() { return transcript_type; }
     int get_start() { return tx_start; }
     int get_end() { return tx_end; }
     char get_strand() { return tx_strand; }
@@ -100,7 +103,7 @@ class Tx {
     Codon get_codon_info(int bp);
     int get_boundary_distance(int bp);
     
-    std::string consequence(int start, int end, std::string alt);
+    std::string consequence(int pos, std::string ref, std::string alt);
 };
 
 #endif  // DENOVONEAR_TX_H_
